@@ -8,8 +8,8 @@ from datalake_scripts.scripts import add_threats, get_threats_by_hashkey, edit_s
 
 
 class Cli:
-    CLI_NAME = 'ocd-dtl'
-    VERSION = '2.6.3'
+    CLI_NAME = "ocd-dtl"
+    VERSION = "2.6.5"
 
     def __init__(self):
         parser = argparse.ArgumentParser(
